@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : REM
-Version : 1.0.0
+Version : 1.0.1
 Author  : Stefano Covino
-Date    : 24/08/2012
+Date    : 22/08/2013
 E-mail  : stefano.covino@brera.inaf.it
 URL     : http://www.me.oa-brera.inaf.it/utenti/covino
 
@@ -14,10 +14,12 @@ Usage   : to be imported
 Remarks :
 
 History : (24/08/2012) First version.
+        : (22/08/2013) Funtions reordered.
 """
 
 
-__all__ = ['Classic', 'devClassic', 'devSimple', 'FindOrigCoord', 'Full', 'minClassic', 'minFull', 'minSimple', 'Simple']
+__all__ = ['Classic', 'FindOrigCoord', 'Full', 'minClassic', 'minFull',
+            'minSimple', 'Simple']
 
 
 PMFlavours = ['classic', 'full', 'simple']
\ No newline at end of file
