@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : REM
-Version : 1.0.15
+Version : 1.0.24
 Author  : Stefano Covino
-Date    : 13/08/2013
+Date    : 24/08/2013
 E-mail  : stefano.covino@brera.inaf.it
 URL     : http://www.me.oa-brera.inaf.it/utenti/covino
 
@@ -28,19 +28,27 @@ History : (16/12/2011) First version.
         : (21/06/2013) New camera code.
         : (01/07/2013) Parameter name check in REM pointing model.
         : (13/08/2013) Better minimization in pointing model computation. V. 1.3.2.
+        : (14/08/2013) V. 1.3.3b1. V. 1.3.3b2.
+        : (15/08/2013) V. 1.3.3b3.
+        : (17/08/2013) V. 1.3.3b4.
+        : (21/08/2013) V. 1.4.0b1., 1.4.0b2.
+        : (22/08/2013) V. 1.4.0b3.
+        : (23/08/2013) V. 1.4.0b4.
+        : (23/08/2013) V. 1.4.0.
 """
 
-__version__ = '1.3.2'
+__version__ = '1.4.0'
 
 
 
-__all__ =  ['GetObj', 'GetREMSite']
+__all__ =  ['GetObj', 'GetREMOffsets', 'GetREMSite']
 
 
 
 # REM pixel size
 REMIRPixSize    = 1.22
 ROSSPixSize     = 0.59
+ROS2PixSize     = 0.59
 
 
 # Constants
@@ -57,5 +65,9 @@ REMLAT = '-29.2567'
 REMLONG = '-70.7292'
 REMHEIGHT = 2347.0
 
+# REM headers
+RA          =   'RA'
+DEC         =   'DEC'
+DOBS        =   'DATE-OBS'
 
 
